@@ -34,7 +34,7 @@ from Products.PyConBrasil.UIDRenamer import UIDRenamer
 from Products.PyConBrasil.config import *
 
 ##code-section module-header #fill in your manual code here
-import transaction##/code-section module-header
+##/code-section module-header
 
 schema = Schema((
 
