@@ -145,11 +145,7 @@ schema = Schema((
     StringField(
         name='tipo',
         widget=SelectionWidget(
-            description=("Tipo da inscrição que está sendo realizada. "
-                         "Estudantes ou Membros APyB: R$ 25,00. "
-                         "Membros SBC ou ABRAWEB: R$ 35,00. "
-                         "Público em geral: R$ 45,00. "
-                         "Palestrantes: isento."),
+            description="Tipo da inscrição que está sendo realizada.",
             condition="not:object/emPreInscricao",
             label='Tipo',
             label_msgid='PyConBrasil_label_tipo',
@@ -161,7 +157,7 @@ schema = Schema((
             ('1', 'Estudante ou Membro APyB'),
             ('2', 'Membro SBC ou Membro ABRAWEB'),
             ('3', 'Público em geral'),
-            ('4', 'Palestrante'),
+            ('4', 'Patrocinador'),
         ),
     ),
 
